/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.cache;

import java.util.Date;
import java.util.Set;

import casa.dodwan.util.KeyBasedTask;
import casa.dodwan.util.TaskManager;
import casa.dodwan.util.TimerTaskProcessor;
import casa.dodwan.util.Verbosity;

public class PersistenceManager implements
				    TimerTaskProcessor<KeyBasedTask<String>> {

	private Cache cache_;

	private TaskManager<KeyBasedTask<String>> taskManager_;

	public Verbosity verbosity = new Verbosity();

	public PersistenceManager(Cache cache) {
	    
	    cache_ = cache;
	    taskManager_ = new TaskManager<KeyBasedTask<String>>(
								 "PersistenceManager");
	}

	// ------------------------------------------------------------
	public void cancel(String key) {
	    
	    if (verbosity.isEnabled())
		System.out.println("PersistenceManager.cancel('" + key + "')");

	    taskManager_.cancel(key);
	}
	
	// ------------------------------------------------------------
	public void clear() {

	    if (verbosity.isEnabled())
		System.out.println("PersistenceManager.clear()");
	    
		taskManager_.clear();
	}
	
	// ------------------------------------------------------------
	public Set getKeys() {
	    
	    return taskManager_.getKeys();
	}
	
	// ------------------------------------------------------------
	public boolean isScheduled(String key) {
	    
		boolean result;
		try {
		    result = taskManager_.containsKey(key);
		} catch (Exception e) {
		    result = false;
		}
		
		if (verbosity.isEnabled())
		    System.out.println("PersistenceManager.isScheduled('" + key
				       + "'): " + result);
		
		return result;
	}
	
	// ------------------------------------------------------------
	public void process(KeyBasedTask<String> task) throws Exception {
	    
	    String key = task.getKey();
	    
	    if (verbosity.isEnabled())
		System.out.println("PersistenceManager.process(task[" + key + "])");
	    
	    cache_.remove(key);
	}
	
	// ------------------------------------------------------------
	public void schedule(String key, Date deadline) throws Exception {
	    
	    if (verbosity.isEnabled())
		System.out.println("PersistenceManager.schedule('" + key + "', "
				   + deadline + ")");
	    
	    taskManager_.schedule(key, new KeyBasedTask<String>(this, key),
				  deadline);
	}
	
	// ------------------------------------------------------------
	public void schedule(String key, long delay) throws Exception {

		if (verbosity.isEnabled())
			System.out.println("PersistenceManager.schedule('" + key + "', "
					+ delay + ")");

		taskManager_.schedule(key, new KeyBasedTask<String>(this, key), delay);
	}

}
