/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.docware;

import casa.dodwan.util.BufferAccessException;
import casa.dodwan.util.Bufferizer;
import casa.dodwan.util.Compressor;

public class ProfileZipBufferizer extends Bufferizer<Profile> {

    private ProfileBufferizer cb_ = new ProfileBufferizer();

    // ------------------------------------------------------------
    public Profile fromBuffer(byte[] buffer, int offset, int length)
	throws BufferAccessException {

	// System.out.println("ProfileZipBufferizer.fromBuffer("
	// 		   + buffer + ", "
	// 		   + offset + ", "
	// 		   + length + ")");

	try {
	    byte[] tmp = Compressor.uncompress(buffer, offset, length);
	    return cb_.fromBuffer(tmp);
	}
	catch (Exception e) {
	    throw new BufferAccessException();
	}
    }

    // ------------------------------------------------------------
    public int toBuffer(Profile prof, byte[] buffer, int offset)
	throws BufferAccessException {
	
	int length = 0;
	try {
	    byte[] tmp1 = cb_.toBuffer(prof);
	    byte[] tmp2 = Compressor.compress(tmp1);
	    System.arraycopy(tmp2, 0, buffer, offset, tmp2.length);
	    length = tmp2.length;
	}
	catch (Exception e) {
	    throw new BufferAccessException();
	}

	// System.out.println("ProfileZipBufferizer.toBuffer(prof, "
	// 		   + buffer + ", "
	// 		   + offset + ") -> "
	// 		   + length);
	
	return length;
    }

    // ------------------------------------------------------------
    public byte[] toBuffer(Profile prof)
	throws BufferAccessException {
	
	byte[] result = null;
	try {
	    byte[] tmp = cb_.toBuffer(prof);
	    result = Compressor.compress(tmp);
	}
	catch (Exception e) {
	    throw new BufferAccessException();
	}

	// System.out.println("ProfileZipBufferizer.toBuffer(prof) -> "
	// 		   + result.length);

	return result;
    }
}
