/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.hub;

import casa.dodwan.config.DodwanEnvironment;
import casa.dodwan.util.ArgumentParsing;
import casa.dodwan.util.Command;
import casa.dodwan.util.SystemEnvironment;
import casa.dodwan.util.TCPConsole;
import casa.dodwan.net.UDP_Channel;

public class bridged {

	// ------------------------------------------------------------
	public static void exit(int error) {
		help();
		Command.exit(error);
	}

	// ------------------------------------------------------------
	public static void help() {
		System.out.println("\n"
				   + "Syntax: bridged [-h] -Dkey=value ...");
	}

	// ------------------------------------------------------------
	public static void main(String[] args) throws Exception {

	    if (ArgumentParsing.searchIndex("-h", args) != -1) {
		exit(0);
	    }

	    DodwanEnvironment env = DodwanEnvironment.getInstance();
	    env.displayProperties();

	    System.out.println("Instantiation of Bridge on " + SystemEnvironment.host);

	    Bridge bridge = new Bridge();

	    int console_port = env.console_port;
	    if (console_port != 0) {
		TCPConsole mainConsole =
		    new TCPConsole(bridge.console(), 
				   console_port);
	    }

	    // Switch Bridge online
	    bridge.online();

	    // Do nothing until a bridge quit is issued on the console
	    bridge.doWait();
	}
}
