/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/


package casa.dodwan.net;

import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.MulticastSocket;
import java.net.NetworkInterface;

import casa.dodwan.util.ArgumentNotFoundException;
import casa.dodwan.util.ArgumentParsing;
import casa.dodwan.util.ArgumentParsingException;
import casa.dodwan.util.Command;

public class receiveUDP implements Runnable {

    private DatagramSocket socket_ = null;
    private byte[] buffer_;
    private DatagramPacket packet_;


    // ------------------------------------------------------------
    public receiveUDP(InetSocketAddress localAddress, 
		      InetAddress ifAddress) 
	throws Exception {
	
	InetAddress inetLocalAddress = localAddress.getAddress();
	System.out.println("LocalAddress "
			   + (inetLocalAddress instanceof Inet4Address?"(IPv4) ":"(IPv6) ")
			   + localAddress);

	NetworkInterface nif = null;

	if (ifAddress != null) {
	    nif = NetworkInterface.getByInetAddress(ifAddress);
	    if (nif == null) {
		System.out.println("Invalid interface address");
		System.exit(1);
	    }
	    else {
		System.out.println("InterfaceAddress "
				   + (ifAddress instanceof Inet4Address?"(IPv4) ":"(IPv6) ")
				   + ifAddress);
	    }
	}
	
	if (localAddress.getAddress().isMulticastAddress()) {
	    socket_ = new MulticastSocket(localAddress.getPort());
	    if (nif == null)
		((MulticastSocket)socket_).joinGroup(localAddress.getAddress());
	    else
		((MulticastSocket)socket_).joinGroup(localAddress, nif);
	}
	else
	    socket_ = new DatagramSocket(localAddress);

	buffer_ = new byte[64500];
	packet_ = new DatagramPacket(buffer_, buffer_.length);
    }

    // ------------------------------------------------------------
    public void run() {

	while (true) {
		
	    try {
		socket_.receive(packet_);

		System.out.println("<- [" 
				   + packet_.getLength()
				   + "] "
				   + packet_.getSocketAddress());
	    }
	    catch (Exception e) {
		System.err.println(e);
	    }
	}
    }

    // ------------------------------------------------------------
    public static void help() {
	System.out
	    .println("\n"
		     + "Syntax: receiveUDP [-la address] [-lp port] {-if address}\n\n"
		     + "Default: la   = 0.0.0.0\n"
		     + "         lp   = 8000\n");
    }
    
    // ------------------------------------------------------------
    public static void main(String[] args) throws Exception {
	
	if (ArgumentParsing.searchIndex("-h", args) != -1) {
	    help();
	    System.exit(0);
	}
	
	String la = "0.0.0.0";
	int lp    = 8000;
	String ia = null;

	try {
	    try {
		la = ArgumentParsing.searchString("-la", args);
	    }
	    catch (ArgumentNotFoundException e) {
	    }
	    
	    try {
		lp = ArgumentParsing.searchInt("-lp", args);
	    }
	    catch (ArgumentNotFoundException e) {
	    }
	    
	    try {
		ia = ArgumentParsing.searchString("-if", args);
	    }
	    catch (ArgumentNotFoundException e) {
	    }
	}
	catch (ArgumentNotFoundException e) {
	    Command.missingArgument(e);
	    System.exit(1);
	}
	catch (ArgumentParsingException e) {
	    Command.parsingException(e);
	    System.exit(1);
	}
	

	InetSocketAddress localAddress = 
	    new InetSocketAddress(la, lp);
	InetAddress ifAddress = null;
	if (ia != null)
	    ifAddress = InetAddress.getByName(ia);

	receiveUDP receiver = new receiveUDP(localAddress, ifAddress);
	receiver.run();
    }
}
