/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/




package casa.dodwan.pubsub;

import casa.dodwan.docware.Descriptor;
import casa.dodwan.util.Listenable;
import casa.util.Processor;
import casa.dodwan.util.Verbosity;

public class PubSubEventDispatcher 
    extends Listenable<PubSubListener> implements PubSubListener 
{

    public Verbosity verbosity = new Verbosity();

    // ------------------------------------------------------------
    public void publish(Descriptor desc) {

	if (verbosity.isEnabled()) {
	    System.out.println("PubSubEventDispatcher.publish("
			       + desc
			       + ")");
	}

	for (PubSubListener listener : getListeners())
	    listener.publish(desc);
    }

    // ------------------------------------------------------------
    public void newMessageReceived(Descriptor desc, 
				   Processor<Descriptor> proc) {

	if (verbosity.isEnabled()) {
	    System.out.println("PubSubEventDispatcher.newMessageReceived("
			       + desc + ", "
			       + proc + ")");
	}

	for (PubSubListener listener : getListeners())
	    listener.newMessageReceived(desc, proc);
    }

}
