/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.pubsub;

import java.io.File;
import java.io.FileOutputStream;
import java.io.PrintStream;

import casa.dodwan.docware.Descriptor;
import casa.util.Processor;


public class PubSubHistoryArchiver 
    implements PubSubListener {

    private PrintStream outPub_ = null;
    private PrintStream outRcv_ = null;

    // ------------------------------------------------------------
    public PubSubHistoryArchiver(File path) {

	try {
	    outPub_ = 
		new PrintStream(new FileOutputStream(new File(path, 
							      "publication.log")));
	    outRcv_ = 
		new PrintStream(new FileOutputStream(new File(path, 
							      "reception.log")));
	}
	catch (Exception e) {
	    System.out.println("PubSubHistoryArchiverd): failed to open log files in " 
			       + path.getAbsoluteFile());
	}
    }

    // ------------------------------------------------------------
    public void publish(Descriptor desc) {

	try {
	    outPub_.println(desc);
	}
	catch (Exception e) {
	    System.out.println("PubSubHistoryArchiver.publish(): failed to write to file");
	}
    }

    // ------------------------------------------------------------
    public void newMessageReceived(Descriptor desc, 
				   Processor<Descriptor> proc) {

	try {
	    outRcv_.println(desc
			    + ","
			    + proc);
	}
	catch (Exception e) {
	    System.out.println("PubSubHistoryArchiver.newMessageReceived(): failed to write to file");
	}
     }

}
