/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.util;

import java.util.Date;

public class ArgumentParsing {

	// ------------------------------------------------------------
	public static long search_hh_mm_ss(String name, String[] args)
			throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		long result;
		try {
			result = DataFormatting.from_hh_mm_ss(args[index + 1]);
		} catch (Exception e) {
			throw new ArgumentParsingException(name);
		}
		return result;
	}
        
        // ------------------------------------------------------------
	public static Date searchDate(String name, String[] args)
			throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		Date result;
		try {
			result = DataFormatting.from_date(args[index + 1]);
		} catch (Exception e) {
			throw new ArgumentParsingException(name);
		}
		return result;
	}
        
	// ------------------------------------------------------------
	public static double searchDouble(String name, String[] args)
			throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		double result;
		try {
			result = Double.parseDouble(args[index + 1]);
		} catch (Exception e) {
			throw new ArgumentParsingException(name);
		}
		return result;
	}
        
	// ------------------------------------------------------------
	public static int searchIndex(String value, String[] args) {
		for (int i = 0; i < args.length; i++)
			if (args[i].equals(value))
				return i;
		return -1;
	}

	// ------------------------------------------------------------
	public static int searchInt(String name, String[] args) throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		int result;
		try {
			result = Integer.parseInt(args[index + 1]);
		} catch (Exception e) {
			throw new ArgumentParsingException(name);
		}
		return result;
	}

	// ------------------------------------------------------------
	public static long searchLong(String name, String[] args) throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		long result;
		try {
			result = Long.parseLong(args[index + 1]);
		} catch (Exception e) {
			throw new ArgumentParsingException(name);
		}
		return result;
	}

	// ------------------------------------------------------------
	public static boolean searchBoolean(String name, String[] args) throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		boolean result;
		try {
			result = Boolean.parseBoolean(args[index + 1]);
		} catch (Exception e) {
			throw new ArgumentParsingException(name);
		}
		return result;
	}

	// ------------------------------------------------------------
	public static String searchString(String name, String[] args)
			throws Exception {

		int index = searchIndex(name, args);
		if (index == -1)
			throw new ArgumentNotFoundException(name);
		if (index == args.length - 1)
			throw new ArgumentParsingException(name);

		return args[index + 1];
	}      
        
	// ------------------------------------------------------------
	public static String[] searchStringArray(String name, String[] args)
			throws Exception {

		int idx = searchIndex(name, args);
		if (idx == -1)
			throw new ArgumentNotFoundException(name);
		if (idx == args.length - 1)
			throw new ArgumentParsingException(name);

		int nb = args.length - idx - 1;

		String[] result = new String[nb];
		for (int i = 0; i < nb; i++) {
			result[i] = args[i + idx + 1];
		}

		return result;
	}
}
