/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.util;

import java.util.HashSet;
import java.util.Set;

public class Hub<E> {

	private Set<VirtualSocket<E>> sockets_ = new HashSet<VirtualSocket<E>>();

	public Verbosity verbosity = new Verbosity();

	// ------------------------------------------------------------
	public synchronized void addSocket(VirtualSocket<E> socket) {
		if (verbosity.isEnabled())
			System.out.println("Provider.addSocket(" + socket + ")");
		sockets_.add(socket);
	}

	// ------------------------------------------------------------
	public synchronized void removeSocket(VirtualSocket<E> socket) {

		if (verbosity.isEnabled())
			System.out.println("Provider.removeSocket(" + socket + ")");
		sockets_.remove(socket);
	}

	// ------------------------------------------------------------
	public synchronized void write(E value) {

		if (verbosity.isEnabled()) {
			System.out.println("Hub.write(" + value + ")");
		}

		for (VirtualSocket<E> socket : sockets_) {
			try {
				socket.receive(value);
			} catch (Exception e) {
				System.out.println("Hub.write(): " + e);
			}
		}
	}

}
