/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.util;

import java.io.File;
import java.util.Collection;
import java.util.HashMap;


public class HybridRepository<OBJ_TYPE> 
    extends FileBasedRepository<OBJ_TYPE> {
    
    protected HashMap<String, OBJ_TYPE> map_ = 
	new HashMap<String, OBJ_TYPE>();

    public Verbosity verbosity = new Verbosity();
    
    // ------------------------------------------------------------
    public HybridRepository(File path,
			    Bufferizer<OBJ_TYPE> bufferizer) {

	super(path, bufferizer);

// 	verbosity.enable();

// 	initialize();
    }

    // ------------------------------------------------------------
    private void initialize() {

	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.initialize()");

	Collection<String> keys = super.getKeys();
	for(String key: keys) {
	    if (verbosity.isEnabled())
		System.out.println("  Loading " + key + " from filesystem");
	    OBJ_TYPE obj = super.get(key);
	    map_.put(key, obj);
	}
    }

    // ------------------------------------------------------------
    public void clear() {
	
	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.clear()");

	super.clear();
	map_.clear();
    }
    
    // ------------------------------------------------------------
    public boolean contains(String key) {

	return map_.containsKey(key);
    }
    
    // ------------------------------------------------------------
    public void delete(String key) {
	
	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.delete(" + key + ")");
	
	if (map_.containsKey(key)) {
	    super.delete(key);
	    map_.remove(key);
	}
    }
    
    // ------------------------------------------------------------
    public OBJ_TYPE get(String key) {

	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.get(" + key + ")");

	return map_.get(key);
    }
    
    // ------------------------------------------------------------
    public Collection<OBJ_TYPE> getElements() {

	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.getElements()");

	return map_.values();
    }
    
    // ------------------------------------------------------------
    public Collection<String> getKeys() {

	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.getKeys()");

	return map_.keySet();
    }
    
    // ------------------------------------------------------------
    public int size() {

	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.size()");

	return map_.size();
    }
    
    // ------------------------------------------------------------
    public void put(String key, OBJ_TYPE obj) {
	
	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.put(" + key + ")");

	super.put(key, obj);
	map_.put(key, obj);
    }
    
    // ------------------------------------------------------------
    public void load(String key, OBJ_TYPE obj) {
	
	if (verbosity.isEnabled())
	    System.out.println("HybridRepository.load(" + key + ")");
	
	map_.put(key, obj);
    }
 }
