/* *****************************************************************************
 * Copyright (c) 2005-2010 VALORIA Laboratory, 
 * Universite Europeenne de Bretagne, Universite de Bretagne-Sud, France
 * <http://www-valoria.univ-ubs/CASA/DoDWAN>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************
 * $Id: MessageTracker.java $
 * ****************************************************************************/

package casa.dodwan.util;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;

/**
 * Parses a log file and produce a messages log file
 */
public class Log2Msg extends LogParser {

    private final Map<String, Long> offsets_ = new HashMap<>();

    public Log2Msg(InputStream in, OutputStream out) {
        super(in, out);
    }

    // ------------------------------------------------------------
    @Override
    public void processEvent(Event event) {

        switch (event.tag) {
            case "time":
                if (event.message.startsWith("<")) {
                    processTime(event);
                }
                break;
            case "pubsub":
                if (event.message.startsWith("> publish")) {
                    processPublish(event);
                }
                break;
            case "provide":
                if (event.message.startsWith("<")
                        && !event.message.endsWith("(dup)")
                        && !event.message.endsWith("(alien)")) {
                    processMessageReceive(event);
                }
                break;
        }
    }

    // ------------------------------------------------------------
    private void processTime(Event event) {

        int idx1 = event.message.indexOf("=");
        int idx2 = event.message.indexOf(",");
        String sdr = event.message.substring(idx1 + 1, idx2);

        idx1 = event.message.indexOf("=", idx2);
        idx1 = event.message.indexOf("=", idx1 + 1);
        idx1 = event.message.indexOf("=", idx1 + 1);
        String str = event.message.substring(idx1 + 1);
        long offset = Long.parseLong(str);

        offsets_.put(sdr + "_" + event.name, offset);
        System.err.println("Got an offset for " + sdr + "_" + event.name
                + ": " + offset);
    }

    // ------------------------------------------------------------
    private void processPublish(Event event) {

        int idx1 = event.message.indexOf("=");
        int idx2 = event.message.indexOf(")");
        String id = event.message.substring(idx1 + 1, idx2);

        out.println(event.time + " snd " + event.name + " " + id);
    }

    // ------------------------------------------------------------
    private void processMessageReceive(Event event) {

        // Let us ignore message fragments other than fragment 0
        if (!event.message.endsWith("/0")) {
            return;
        }

        int idx1 = event.message.indexOf("=");
        int idx2 = event.message.indexOf(",");
        String sdr = event.message.substring(idx1 + 1, idx2);

        idx1 = event.message.indexOf("=", idx2);
        idx2 = event.message.indexOf("/");
        String id = event.message.substring(idx1 + 1, idx2);

        long rcvTime = event.time;
        String rcv = event.name;
        String offsetId = sdr + "_" + rcv;
        if (offsets_.containsKey(offsetId)) {
            long offset = offsets_.get(offsetId);
            rcvTime -= offset;
            System.err.println("Adjusting rcv time for " + offsetId);
        }

        out.println(rcvTime + " rcv " + event.name + " " + id + " sdr=" + sdr);
    }

    // ------------------------------------------------------------
    public static void usage() {
        System.out.println("java DodwanMessageParser [ref_time] [-|logfile]");
        System.out.println("Reads a log file on stdin and produces a messages log file to stdout.");
        System.exit(0);
    }

    // ------------------------------------------------------------
    public static void main(String[] args) throws IOException {
        if (args.length < 1 || args[0].equals("-h")) {
            usage();
        }

        String option = args[args.length - 1];
        InputStream is = (option.equals("-") 
                ? System.in 
                : new FileInputStream(option));

        Log2Msg parser = new Log2Msg(is, System.out);
        if (args.length > 1) {
            parser.setRefTime(Long.parseLong(args[0]));
        }

        parser.parse();

    }
}
