/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.util;

import java.util.Collection;
import java.util.HashMap;


public class MemoryBasedRepository<KEY_TYPE, OBJ_TYPE> 
    implements Repository<KEY_TYPE, OBJ_TYPE> {
    
    protected HashMap<KEY_TYPE, OBJ_TYPE> map_ = new HashMap<KEY_TYPE, OBJ_TYPE>();
    
    public Verbosity verbosity = new Verbosity();
    


    // ------------------------------------------------------------
    public MemoryBasedRepository() {

// 	verbosity.enable();
    }

    // ------------------------------------------------------------
    public void clear() {

	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.clear()");
	
	map_.clear();
    }
    
    // ------------------------------------------------------------
    public boolean contains(KEY_TYPE key) {
	return map_.containsKey(key);
    }
    
    // ------------------------------------------------------------
    public void delete(KEY_TYPE key) {
	
	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.delete(" + key + ")");
	
	map_.remove(key);
    }
    
    // ------------------------------------------------------------
    public OBJ_TYPE get(KEY_TYPE key) {
	
	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.get(" + key + ")");
	
	return map_.get(key);
    }
    
    // ------------------------------------------------------------
    public Collection<OBJ_TYPE> getElements() {

	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.getElements()");
	
	return map_.values();
    }
    
    // ------------------------------------------------------------
    public Collection<KEY_TYPE> getKeys() {

	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.getKeys()");
	
	return map_.keySet();
    }
    
    // ------------------------------------------------------------
    public int size() {

	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.size()");
	
	return map_.size();
    }
    
    // ------------------------------------------------------------
    public void put(KEY_TYPE key, OBJ_TYPE obj) {
	
	if (verbosity.isEnabled())
	    System.out.println("MemoryBasedRepository.put(" + key + ")");
	
	map_.put(key, obj);
    }
    
}
