/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.util;

/**
 * A <code>Source&lt;E&gt;</code> is an entity objects of type <code>E</code>
 * can be read from, using a blocking method <code>read()</code>.
 * <p>
 * 
 * @author $Author: F. Guidec$
 * @version $Revision: 1.0$
 */
public interface Source<E> {

	/**
	 * Returns an object of type <code>E</code>. This method blocks until such
	 * an object can be returned (or until an exception must be raised).
	 * 
	 * @return an object of type <code>E</code>.
	 */
	public E read() throws Exception;

}
