/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/


package casa.dodwan.util;

import casa.dodwan.util.Console;
import casa.dodwan.util.ConsoleServer;


/**
 * Defines a command interpreter and a TCP socket server.
 */
public class TCPConsole {

    private Console console_ = null ;
    private ConsoleServer server_ = null;
    
    
    // --------------------------------------------------------------------------
    /**
     * Creates a command interpreter and a  daemon thread thats accept and
     * execute commands received on TCP sockets, on dedicated ports. The
     * first one maintains a connection (on port <code>console_port</code>) for
     * a stream of commands until a quit command is issued.  The second one
     * opens a new connection (on port <code>console_port + 1</code>) for a
     * single command.
     */
    public TCPConsole(String key, String prefix, Console console, int console_port) {
    	Console cons = new Console();
    	cons.addSubConsole(key, prefix, console);
	init(cons, console_port);
    }

    /**
     * Creates a command interpreter and a ConsoleServer that accepts
     * and executes commands received on a TCP socket.
     */
    public TCPConsole(Console console, int console_port) {
	init(console, console_port);
    }

    // ------------------------------------------------------------
    /**
     * Returns the port number served by this TCPConsole.
     */
    public int getLocalPort() {
	if (server_ ==  null)
	    return -1;
	return server_.getLocalPort();
    }

    // ------------------------------------------------------------
    private void init(Console console, int port) {
    	console_ = console;
    	console_.quitAllowed(true);  

    	// Creates and starts a persistent server on port (port)
    	try {
	    server_ = new ConsoleServer(port, console_);
	    server_.setDaemon(true);
	    server_.start();
    	}
    	catch (Exception e) {
    		System.err.println("TCPConsole: could not initiate a console server on TCP port #"
    				+ port);
    	}
    }

    // --------------------------------------------------------------------------
    /**
      * @undocumented
     */
    public Console getConsole() {
    	return console_;
    }
 
    // --------------------------------------------------------------------------
    /**
      * @undocumented
     */
    public void close() {
    	server_.close();
    	return ;
    }

 

}

