/* *****************************************************************************
 * Copyright (c) IRISA Laboratory, 
 * Universite Bretagne Sud, France
 * <http://www-casa.irisa.fr/dodwan>
 *
 * This file is part of DoDWAN.
 * 
 * DoDWAN is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software 
 * Foundation, either version 3 of the License, or any later
 * version.
 * 
 * DoDWAN is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * DoDWAN.  If not, see <http://www.gnu.org/licenses/>.
 * ****************************************************************************/



package casa.dodwan.util;

public class VirtualSocket<E> implements Socket<E> {

	private Hub hub_;

	private E value_ = null;

	public Verbosity verbosity = new Verbosity();

	// ------------------------------------------------------------
	public VirtualSocket(Hub hub) {

		hub_ = hub;
	}

	// ------------------------------------------------------------
	public synchronized E read() throws Exception {

		if (value_ == null)
			this.wait();

		if (verbosity.isEnabled())
			System.out.println("VirtualSocket.read(): '" + value_ + "'");

		E result = value_;
		value_ = null;
		this.notify();
		return result;
	}

	// ------------------------------------------------------------
	public synchronized void receive(E value) throws Exception {

		if (value_ != null)
			this.wait();

		value_ = value;
		this.notify();
	}

	// ------------------------------------------------------------
	public void write(E value) throws Exception {

		if (verbosity.isEnabled())
			System.out.println("VirtualSocket.write('" + value + "')");

		hub_.write(value);
	}

}
